"""
Fabric Warehouse Advisor — Performance Checks
================================================
Individual check modules for different performance aspects.

These modules are **internal** to the performance-check advisor.
They are orchestrated by :class:`PerformanceCheckAdvisor` and should
not be called directly by end users.
"""
